<?php

namespace app\models;

use Yii;
use app\behaviours\ActiveRecordLogableBehavior;
use yii\behaviors\TimestampBehavior;
use yii\db\ActiveRecord;
use app\base\Converter;
use app\models\Boxidref;
use app\base\Common;

/**
 * This is the model class for table "{{%labdeptmaster}}".
 *
 * @property integer $recid
 * @property string $dept_code
 * @property string $occu_name
 * @property string $status
 * @property integer $create_time
 * @property integer $create_user
 * @property integer $update_time
 * @property integer $update_user
 */
class Vltransupdate extends \yii\db\ActiveRecord
{
    /**
     * @inheritdoc
     */
	 
	public $statusdum = [1 => "Y", 0 => "N"]; 
	public $deliverytype = [1 => "Hand Delivery", 2 => "Courier"];	
	public $artc;
	
    public static function tableName()
    {
        return 'vltransportation';
    }
		
    /**
     * @inheritdoc
     */
	public function behaviors()
	{
		return [
			
			[
				'class' => TimestampBehavior::className(),
				'createdAtAttribute' => 'create_time',
				'updatedAtAttribute' => 'update_time',
				'value' => date('U'),
			],
		];
	}

    /**
     * @inheritdoc
     */
    public function rules()
    {
        return [
            [['district','artcname','artccode','cdate','rvll','rvllname','tmech','staffcode','staffname'], 'required'],          
			[['boxid','rdate','rtime','rperson','noofsample'], 'safe'],
			
			//[['artccode', 'boxid'], 'unique', 'targetAttribute' => ['artccode', 'boxid'], 'message' => 'The combination of ARTC Code and Box ID has already been taken.'],

           	[['couriername','podref'], 'required', 'message' => 'Cannot be blank.', 'when' => function ($model) {	
               return $model->tmech == 2;			 
			 }, 'whenClient' => "function (attribute, value) {				
				return $('#vltransupdate-tmech').val() == 2;
			}"],	
			
			[['rtime'], 'required', 'message' => 'Cannot be blank.', 'when' => function ($model) {	
               return $model->rdate != '';			 
			 }, 'whenClient' => "function (attribute, value) {				
				return $('#vltransupdate-rdate').val() != '';
			}"],	
			
			[['rdate'], 'rdateValidate'],	
			[['rtime'], 'rtimeValidate','on'=>'update'],	
			[['podref'], 'podValidate'],	           			
			
            [['noofsample','create_time', 'create_user', 'update_time', 'update_user'], 'integer'],	
            [['noofsample'], 'string', 'max' => 3],				
            [['status'], 'string', 'max' => 1],
			[['record_date'], 'default', 'value' => strtotime(date('Y/m/d'))],
        ];
    }
	

    /**
     * @inheritdoc
     */
    public function attributeLabels()
    {
        return [		   
            'district' => Yii::t('app', 'District'),
			'artcname'=> Yii::t('app', 'Name of the ART Centre'),
			'artccode'=> Yii::t('app', 'ART Centre Code'),
			'staffcode' => Yii::t('app', 'Staff Code'),
			'staffname' => Yii::t('app', 'Staff Name'),
			'cdate' => Yii::t('app', 'Consignment Date'),
			'boxid' => Yii::t('app', 'Box ID'),
			'rvll' => Yii::t('app', 'Viral Load Lab Code'),
			'rvllname' => Yii::t('app', 'Viral Load Lab Name'),
			'rdate' => Yii::t('app', 'Receiving Date'),
			'rtime' => Yii::t('app', 'Receiving Time'),
			'rperson' => Yii::t('app', 'Receiver Name'),
			'tmech' => Yii::t('app', 'Delivery Mode'),
			'couriername' => Yii::t('app', 'Name of Courier'),
			'podref' => Yii::t('app', 'POD Reference Number'),
			'podref' => Yii::t('app', 'POD Reference Number'),
			'noofsample' => Yii::t('app', 'No of Samples'),
			
            'status' => Yii::t('app', 'Status'),
            'create_time' => Yii::t('app', 'Created Time'),
            'create_user' => Yii::t('app', 'Created By'),
            'update_time' => Yii::t('app', 'Updated Time'),
            'update_user' => Yii::t('app', 'Updated By'),
        ];
    }
	
	
	 public function podValidate($attribute, $params) {
        if($this->podref != "") :
			$Model= parent::find()->where(["podref" => $this->podref])->orderBy(["recid" => SORT_ASC])->one();			
            if($Model !== null) {
			  if($Model->recid != $this->recid) 
			     $this->addError($attribute, "POD Reference Number Already Exists.");
             }				
        endif;
	}
		
	public function rdateValidate($attribute, $params) {
        if($this->cdate != "" && $this->rdate != "" ) :
		    
		  $this->cdate = Converter::toStore($this->cdate);
		  $this->rdate = Converter::toStore($this->rdate);
		//  $this->addError($attribute, 'Receiving Date Cannot be Lesser than Consignment Date'.$this->rdate."-".$this->cdate);
	 
	  if($this->cdate > $this->rdate) {
	    	   $this->addError($attribute, 'Receiving Date Cannot be Lesser than Consignment Date');
			   $this->rdate = Converter::toDisplay($this->rdate);	
			   $this->cdate = Converter::toDisplay($this->cdate);
	         }
             else {
			    $this->rdate = Converter::toDisplay($this->rdate);
                $this->cdate = Converter::toDisplay($this->cdate);		
			  }				
	   		
        endif;
	}
	
	public function rtimeValidate($attribute, $params) {
       if($this->cdate != "" && $this->rtime != "" ) :
	   
	    $dayintime = $this->cdate." ".$this->rtime;
		$todaytime = time();
		$dayintime= strtotime($dayintime);		
		$tf=$dayintime-$todaytime;			
	     
        $consignmentdate = Converter::toStore($this->cdate);	
		$today =strtotime(date('Y/m/d'));
	         
		 if($consignmentdate === $today && $tf < -60) {
	   	  	    $this->addError($attribute, 'Wrong Time. Receiving time Cannot be Lesser than Current Time');	
	      }
		 
        endif;
	}
	
	 public function getStatusdum()
	 {
		return $this->statusdum[$this->status];
		
	 }
	 
   public function getDistrictmaster($id)
	{
		$Gmodel = \app\models\District::find()->where(["district" => $id])->one();
		if($Gmodel !== null) 
		    return $Gmodel->district;
		 else
			return "-";
	}
	
	 public function getArtcmaster($id)
	{
		$Gmodel = \app\models\Artcentre::find()->where(["artccode" => $id])->one();
		if($Gmodel !== null) 
		    return $Gmodel->artccode;
		 else
			return "-";
	}
	
	public function getArtcname($id)
	{
		$Gmodel = \app\models\Artcentre::find()->where(["artcname" => $id])->one();
		if($Gmodel !== null) 
		    return $Gmodel->artcname;
		 else
			return "-";
	}
	
	 public function beforeSave($insert)
	{
		if (parent::beforeSave($insert)) {		
			 
			 if($this->cdate != "")
				$this->cdate = Converter::toStore($this->cdate);				 
			 if($this->rdate != "")
				$this->rdate = Converter::toStore($this->rdate);  
			 if($this->rdate != "" && $this->rtime != "")
				$this->rtime = date('H:i', strtotime($this->rtime)); 
             if($this->rdate == "")
				$this->rtime = Null;			
			
	        return true;
	    } else {
	        return false;
	    }
	}
	
	public function afterFind()
	{
		parent::afterFind();
		if(Yii::$app->controller->action->id != "view") {
			if($this->cdate != "")
				$this->cdate = Converter::toDisplay($this->cdate);			
			if($this->rdate != "")
				$this->rdate = Converter::toDisplay($this->rdate);
           // if($this->rtime != "")
           //    $this->rtime = Yii::$app->formatter->asTime($this->rtime, 'medium');			
           
		}
	}
	
}
